@@ -269,7 +269,31 @@ class Text:
         reshaped_text = arabic_reshaper.reshape(text)
         return get_display(reshaped_text)
 
+    def CInput(self,text,completer=lambda text,state:[],clear_history=True):
+        def _completer(text, state):
+            return [i for i in completer if i.startswith(text)][state]
+
+        import readline
+        if clear_history:
+            readline.clear_history()
+        if type(completer) == type(_completer):
+            readline.parse_and_bind("tab: complete")
+            readline.set_completer(completer)
+        elif type(completer) == list:
+            readline.parse_and_bind("tab: complete")
+            readline.set_completer(_completer)
+        else:
+            raise TypeError('completer accept only [ function or list ]')
+        return input(Color().reader(text))
+
 class Square:
+    square=['╔', '║', '╚', '═', '╝', '║', '╗', '═']
+    spacing=0
+    padding= [0, 0, 0, 0]
+    color=''
+    cols=0
+    equal=True
+    center=False
     def __init__(self):
         self.SETTINGS = {
             'square':['╔', '║', '╚', '═', '╝', '║', '╗', '═'],
@@ -385,109 +409,97 @@ class Square:
         output += '\n'+CO+SQUARE[2]+CO+(SQUARE[3]*text_size['width'])+CO+SQUARE[4]+'[$NORMAL]' # .... ╚═════╝
         return Color().reader(output)
 
-class Animation:
-    def Loading(self,text='Loading...',anim=['/','-','\\','|']):
-        while True:
-            for i in anim:
-                yield text+i
+class AnimationTools:
+    def __init__(self):
+        self.load_anim = self.set_load_anim(['/', '-', '\\', '|'])
+        self.text_anim = self.set_text_anim('Loading')
 
-    def SlowText(self,text,timer=0.1):
+    def set_load_anim(self,List):
+        while True:
+            for i in List:
+                yield i
+
+    def set_text_anim(self,text):
+        while True:
+            for i in range(0,len(text)):
+                t1 = text[:i]
+                t2 = text[i].upper() if text[i] != text[i].upper() else text[i].lower()
+                t3 = text[i+1:]
+                yield t1+t2+t3
+
+AnimationTools = AnimationTools()
+
+class Animation:
+    def SlowText(self, text, timer=0.1):
         '''to write text by Index(System) slow motion'''
         for i in text:
             sys.stdout.write(i)
             sys.stdout.flush()
             time.sleep(timer)
 
-    def SlowLine(self,text,timer=0.5):
+    def SlowLine(self, text, timer=0.5):
         '''to write text by Line as slow motion'''
         for i in text.split('\n'):
             print(i)
             time.sleep(timer)
 
+    def Loading(self, text='Loading...'):
+        if str(type(text)) == "<class 'generator'>":
+            text = next(text)
+        anim = next(AnimationTools.load_anim)
+        return [text+anim]
+
+    def Prograsse(self,prograsse=['│','█','▒','│'],text='Loading',width=24,min=1,max=10):
+        text = Color().reader(str(text))
+        prograsse = [Color().reader(str(i)) for i in prograsse]
+        i = width*min//max
+        return ['\r'+text+prograsse[0]+(i*prograsse[1])+(prograsse[2]*(width-i))+prograsse[3]+' ']
+
 class ThreadAnimation:
-    def __init__(self):
-        self.kill = False
-        self.timer = .2
-        self.END = 'DONE...!'
-        self.ANIMATION = None
+    def __init__(self,Animation=Animation().Loading,kwargs={},timer=.2):
+        self.timer = timer
+        self.Animation = Animation
+        self.kwargs = kwargs
 
-    def set_animation(self,ANIMATION,END=None):
-        '''
-        to set Animation.
-        example:
-        ... def MyAnimation():
-        ...     while True:
-        ...         for i in 'Loading':
-        ...             yield f'Loading...( {i} )'
-        ...
-        ... TA = ThreadAnimation()
-        ... TA.set_animation( MyAnimation(), END='DONE...!' )
-        ...
-        ... with TA:
-        ...     for i in range(10000000):
-        ...         pass
-        ... print (i)
-        '''
-        self.ANIMATION = ANIMATION
-        self.END = END if END != None else self.END
+    def kill(self):
+        self._kill = True
+        self.THREAD_ANIM.join()
 
-    def thread(self,func):
-        '''
-        function thread.
-        example:
-        ... TA = ThreadAnimation()
-        ... TA.set_animation( MyAnimation() )
-        ...
-        ... @TA.thread
-        ... def my_function():
-        ...     for i in range(10000000):
-        ...         pass
-        ...     return i
-        ...
-        ... print( my_function() )
+    def set_end(self,text):
+        self.END = Color().reader(str(text))
 
-        '''
-        def wrapper(*args,**kwargs):
-            self.__enter__()
-            rv = func(*args,**kwargs)
-            self.kill = True
-            self.THREAD_ANIM.join()
-            return rv
-        return wrapper
+    def set_kwargs(self,**kwargs):
+        self.kwargs = kwargs
 
-    def __enter__(self):
-        '''
-        example:
-        ... TA = ThreadAnimation()
-        ... TA.set_animation( MyAnimation(), END='DONE...!' )
-        ...
-        ... with TA as thread:
-        ...     for i in range(10000000):
-        ...         pass
-        ...     print(thread.is_alive())
-        ...
-        ... print (thread.is_alive())
-        ... print (i)
-        '''
-        self.kill = False
-        def anim():
-            size = 0
-            for text in self.ANIMATION:
+    def _anim(self):
+        size = 0
+        while True:
+            _Animation = self.Animation(**self.kwargs)
+            for text in _Animation:
                 text = Color().reader(text+'[$NORMAL]')
-                if self.kill:
-                    print('\r'+self.END+' '*(size-len(self.END) if len(self.END) < size else 0))
-                    break
-
+                if self._kill:break
                 sys.stdout.write('\r'+text)
                 size = len(Color().del_colors(text))
                 time.sleep(self.timer)
+            if self._kill:
+                print('\r' + (' ' *size),end='\r')
+                try:
+                    print('\r' + self.END)
+                except AttributeError:
+                    pass
+                break
 
-        self.THREAD_ANIM = threading.Thread(target=anim)
+    def start_loop(self):
+        self._kill = False
+        self.THREAD_ANIM = threading.Thread(target=self._anim)
         self.THREAD_ANIM.daemon = True
         self.THREAD_ANIM.start()
 
-        return self.THREAD_ANIM
-
-    def __exit__(self, exc_type, exc_val, exc_tb):
-        self.kill = True
-        self.THREAD_ANIM.join()
\ No newline at end of file
+    def __call__(self, func, *args, **kwargs):
+        def wrapper(*args, **kwargs):
+            self.start_loop()
+            rv = func(self,*args, **kwargs)
+            self._kill = True
+            self.THREAD_ANIM.join()
+            return rv
+        return wrapper
\ No newline at end of file
